============
Deprecations
============

Features deprecated in 0.9.0
============================

Methods
-------

* The :meth:`.environ.Env.unicode` method is deprecated as it was used
  for Python 2.x only. Use :meth:`.environ.Env.str` instead.
